@@ -63,6 +63,9 @@ impl TextMapListDataset {
     pub fn get(&self, key : Cow<'static, str>) -> Option<&Vec<Cow<'static, str>>> {
         self.data.get(&key)
     }
+    pub fn internal_ref(&self) -> &BTreeMap<Cow<'static, str>, Vec<Cow<'static, str>>> {
+        &self.data
+    }
 }
 
 #[cfg(test)]
